pub struct TypedQueryClient { /* private fields */ }Expand description
A typed query client over the chain RPC abci_query transport.
Implementations
Sourceimpl TypedQueryClient
impl TypedQueryClient
Sourcepub fn new(rpc_url: impl Into<String>) -> Self
pub fn new(rpc_url: impl Into<String>) -> Self
Creates a typed query client targeting the chain RPC URL.
Sourcepub fn with_rpc(rpc: JsonRpcClient) -> Self
pub fn with_rpc(rpc: JsonRpcClient) -> Self
Wraps an existing JsonRpcClient.
Sourcepub async fn pqc_account(
&self,
address: impl Into<String>,
) -> Result<QueryAccountResponse>
pub async fn pqc_account( &self, address: impl Into<String>, ) -> Result<QueryAccountResponse>
Queries qorechain.pqc.v1.Query/Account.
Sourcepub async fn crossvm_params(&self) -> Result<QueryParamsResponse>
pub async fn crossvm_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.crossvm.v1.Query/Params.
Sourcepub async fn crossvm_pending_messages(
&self,
) -> Result<QueryPendingMessagesResponse>
pub async fn crossvm_pending_messages( &self, ) -> Result<QueryPendingMessagesResponse>
Queries qorechain.crossvm.v1.Query/PendingMessages.
Sourcepub async fn crossvm_message(
&self,
id: impl Into<String>,
) -> Result<QueryMessageResponse>
pub async fn crossvm_message( &self, id: impl Into<String>, ) -> Result<QueryMessageResponse>
Queries qorechain.crossvm.v1.Query/Message.
Sourcepub async fn lightnode(
&self,
address: impl Into<String>,
) -> Result<QueryLightNodeResponse>
pub async fn lightnode( &self, address: impl Into<String>, ) -> Result<QueryLightNodeResponse>
Queries qorechain.lightnode.v1.Query/LightNode.
Sourcepub async fn lightnodes(&self) -> Result<QueryLightNodesResponse>
pub async fn lightnodes(&self) -> Result<QueryLightNodesResponse>
Queries qorechain.lightnode.v1.Query/LightNodes.
Sourcepub async fn lightnode_params(&self) -> Result<QueryParamsResponse>
pub async fn lightnode_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.lightnode.v1.Query/Params.
Sourcepub async fn lightnode_rewards(
&self,
address: impl Into<String>,
) -> Result<QueryRewardsResponse>
pub async fn lightnode_rewards( &self, address: impl Into<String>, ) -> Result<QueryRewardsResponse>
Queries qorechain.lightnode.v1.Query/Rewards.
Sourcepub async fn lightnode_stats(&self) -> Result<QueryStatsResponse>
pub async fn lightnode_stats(&self) -> Result<QueryStatsResponse>
Queries qorechain.lightnode.v1.Query/Stats.
Sourcepub async fn svm_slot(&self) -> Result<QuerySlotResponse>
pub async fn svm_slot(&self) -> Result<QuerySlotResponse>
Queries qorechain.svm.v1.Query/Slot.
Sourcepub async fn svm_account(
&self,
address: impl Into<String>,
) -> Result<QueryAccountResponse>
pub async fn svm_account( &self, address: impl Into<String>, ) -> Result<QueryAccountResponse>
Queries qorechain.svm.v1.Query/Account.
Sourcepub async fn svm_program(
&self,
address: impl Into<String>,
) -> Result<QueryProgramResponse>
pub async fn svm_program( &self, address: impl Into<String>, ) -> Result<QueryProgramResponse>
Queries qorechain.svm.v1.Query/Program.
Sourcepub async fn reputation_params(&self) -> Result<QueryParamsResponse>
pub async fn reputation_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.reputation.v1.Query/Params.
Sourcepub async fn qca_config(&self) -> Result<QueryConfigResponse>
pub async fn qca_config(&self) -> Result<QueryConfigResponse>
Queries qorechain.qca.v1.Query/Config.
Sourcepub async fn rlconsensus_agent_status(&self) -> Result<QueryAgentStatusResponse>
pub async fn rlconsensus_agent_status(&self) -> Result<QueryAgentStatusResponse>
Queries qorechain.rlconsensus.v1.Query/AgentStatus.
Sourcepub async fn rlconsensus_params(&self) -> Result<QueryParamsResponse>
pub async fn rlconsensus_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.rlconsensus.v1.Query/Params.
Sourcepub async fn rlconsensus_observation(&self) -> Result<QueryObservationResponse>
pub async fn rlconsensus_observation(&self) -> Result<QueryObservationResponse>
Queries qorechain.rlconsensus.v1.Query/Observation.
Sourcepub async fn rlconsensus_reward(&self) -> Result<QueryRewardResponse>
pub async fn rlconsensus_reward(&self) -> Result<QueryRewardResponse>
Queries qorechain.rlconsensus.v1.Query/Reward.
Sourcepub async fn rlconsensus_policy(&self) -> Result<QueryPolicyResponse>
pub async fn rlconsensus_policy(&self) -> Result<QueryPolicyResponse>
Queries qorechain.rlconsensus.v1.Query/Policy.
Sourcepub async fn multilayer_params(&self) -> Result<QueryParamsResponse>
pub async fn multilayer_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.multilayer.v1.Query/Params.
Sourcepub async fn multilayer_layer(
&self,
layer_id: impl Into<String>,
) -> Result<QueryLayerResponse>
pub async fn multilayer_layer( &self, layer_id: impl Into<String>, ) -> Result<QueryLayerResponse>
Queries qorechain.multilayer.v1.Query/Layer.
Sourcepub async fn multilayer_layers(&self) -> Result<QueryLayersResponse>
pub async fn multilayer_layers(&self) -> Result<QueryLayersResponse>
Queries qorechain.multilayer.v1.Query/Layers.
Sourcepub async fn multilayer_anchor(
&self,
layer_id: impl Into<String>,
) -> Result<QueryAnchorResponse>
pub async fn multilayer_anchor( &self, layer_id: impl Into<String>, ) -> Result<QueryAnchorResponse>
Queries qorechain.multilayer.v1.Query/Anchor — the latest state anchor
for a layer.
Sourcepub async fn multilayer_anchors(
&self,
layer_id: impl Into<String>,
) -> Result<QueryAnchorsResponse>
pub async fn multilayer_anchors( &self, layer_id: impl Into<String>, ) -> Result<QueryAnchorsResponse>
Queries qorechain.multilayer.v1.Query/Anchors — all state anchors for a
layer (newest first).
Sourcepub async fn multilayer_routing_stats(&self) -> Result<QueryRoutingStatsView>
pub async fn multilayer_routing_stats(&self) -> Result<QueryRoutingStatsView>
Queries qorechain.multilayer.v1.Query/RoutingStats.
Sourcepub async fn amm_params(&self) -> Result<QueryParamsResponse>
pub async fn amm_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.amm.v1.Query/Params.
Sourcepub async fn amm_pool(&self, pool_id: u64) -> Result<QueryPoolResponse>
pub async fn amm_pool(&self, pool_id: u64) -> Result<QueryPoolResponse>
Queries qorechain.amm.v1.Query/Pool.
Sourcepub async fn amm_pools(&self) -> Result<QueryPoolsResponse>
pub async fn amm_pools(&self) -> Result<QueryPoolsResponse>
Queries qorechain.amm.v1.Query/Pools.
Sourcepub async fn amm_pool_by_denoms(
&self,
denom_a: impl Into<String>,
denom_b: impl Into<String>,
) -> Result<QueryPoolByDenomsResponse>
pub async fn amm_pool_by_denoms( &self, denom_a: impl Into<String>, denom_b: impl Into<String>, ) -> Result<QueryPoolByDenomsResponse>
Queries qorechain.amm.v1.Query/PoolByDenoms.
Sourcepub async fn amm_lp_balance(
&self,
pool_id: u64,
address: impl Into<String>,
) -> Result<QueryLpBalanceResponse>
pub async fn amm_lp_balance( &self, pool_id: u64, address: impl Into<String>, ) -> Result<QueryLpBalanceResponse>
Queries qorechain.amm.v1.Query/LPBalance.
Sourcepub async fn amm_quote_exact_in(
&self,
pool_id: u64,
denom_in: impl Into<String>,
amount_in: impl Into<String>,
) -> Result<QueryQuoteExactInResponse>
pub async fn amm_quote_exact_in( &self, pool_id: u64, denom_in: impl Into<String>, amount_in: impl Into<String>, ) -> Result<QueryQuoteExactInResponse>
Queries qorechain.amm.v1.Query/QuoteExactIn.
Sourcepub async fn amm_quote_exact_out(
&self,
pool_id: u64,
denom_out: impl Into<String>,
amount_out: impl Into<String>,
) -> Result<QueryQuoteExactOutResponse>
pub async fn amm_quote_exact_out( &self, pool_id: u64, denom_out: impl Into<String>, amount_out: impl Into<String>, ) -> Result<QueryQuoteExactOutResponse>
Queries qorechain.amm.v1.Query/QuoteExactOut.
Sourcepub async fn license_check(
&self,
grantee: impl Into<String>,
feature_id: impl Into<String>,
) -> Result<QueryCheckResponse>
pub async fn license_check( &self, grantee: impl Into<String>, feature_id: impl Into<String>, ) -> Result<QueryCheckResponse>
Queries qorechain.license.v1.Query/Check.
Sourcepub async fn license_holders(
&self,
feature_id: impl Into<String>,
) -> Result<QueryHoldersResponse>
pub async fn license_holders( &self, feature_id: impl Into<String>, ) -> Result<QueryHoldersResponse>
Queries qorechain.license.v1.Query/Holders.
Sourcepub async fn license_list(
&self,
grantee: impl Into<String>,
) -> Result<QueryListResponse>
pub async fn license_list( &self, grantee: impl Into<String>, ) -> Result<QueryListResponse>
Queries qorechain.license.v1.Query/List.
Sourcepub async fn abstractaccount_config(&self) -> Result<QueryConfigResponse>
pub async fn abstractaccount_config(&self) -> Result<QueryConfigResponse>
Queries qorechain.abstractaccount.v1.Query/Config.
Sourcepub async fn abstractaccount_account(
&self,
address: impl Into<String>,
) -> Result<QueryAccountResponse>
pub async fn abstractaccount_account( &self, address: impl Into<String>, ) -> Result<QueryAccountResponse>
Queries qorechain.abstractaccount.v1.Query/Account.
Sourcepub async fn abstractaccount_accounts(&self) -> Result<QueryAccountsResponse>
pub async fn abstractaccount_accounts(&self) -> Result<QueryAccountsResponse>
Queries qorechain.abstractaccount.v1.Query/Accounts.
Sourcepub async fn abstractaccount_permission_schema(
&self,
) -> Result<QueryPermissionSchemaResponse>
pub async fn abstractaccount_permission_schema( &self, ) -> Result<QueryPermissionSchemaResponse>
Queries qorechain.abstractaccount.v1.Query/PermissionSchema — the
canonical authenticator permission taxonomy (v3.1.85), so clients validate
scopes without hardcoding strings and detect drift via schema_version.
Sourcepub async fn rdk_params(&self) -> Result<QueryParamsResponse>
pub async fn rdk_params(&self) -> Result<QueryParamsResponse>
Queries qorechain.rdk.v1.Query/Params.
Sourcepub async fn rdk_rollup(
&self,
rollup_id: impl Into<String>,
) -> Result<QueryRollupResponse>
pub async fn rdk_rollup( &self, rollup_id: impl Into<String>, ) -> Result<QueryRollupResponse>
Queries qorechain.rdk.v1.Query/Rollup.
Sourcepub async fn rdk_rollups(&self) -> Result<QueryRollupsResponse>
pub async fn rdk_rollups(&self) -> Result<QueryRollupsResponse>
Queries qorechain.rdk.v1.Query/Rollups.
Sourcepub async fn rdk_batch(
&self,
rollup_id: impl Into<String>,
batch_index: u64,
) -> Result<QueryBatchResponse>
pub async fn rdk_batch( &self, rollup_id: impl Into<String>, batch_index: u64, ) -> Result<QueryBatchResponse>
Queries qorechain.rdk.v1.Query/Batch.
Sourcepub async fn rdk_latest_batch(
&self,
rollup_id: impl Into<String>,
) -> Result<QueryLatestBatchResponse>
pub async fn rdk_latest_batch( &self, rollup_id: impl Into<String>, ) -> Result<QueryLatestBatchResponse>
Queries qorechain.rdk.v1.Query/LatestBatch.
Sourcepub async fn bridge_config(&self) -> Result<QueryConfigResponse>
pub async fn bridge_config(&self) -> Result<QueryConfigResponse>
Queries qorechain.bridge.v1.Query/Config.
Sourcepub async fn bridge_chain_config(
&self,
chain_id: impl Into<String>,
) -> Result<QueryChainConfigResponse>
pub async fn bridge_chain_config( &self, chain_id: impl Into<String>, ) -> Result<QueryChainConfigResponse>
Queries qorechain.bridge.v1.Query/ChainConfig.
Sourcepub async fn bridge_chain_configs(&self) -> Result<QueryChainConfigsResponse>
pub async fn bridge_chain_configs(&self) -> Result<QueryChainConfigsResponse>
Queries qorechain.bridge.v1.Query/ChainConfigs.
Sourcepub async fn bridge_validator(
&self,
address: impl Into<String>,
) -> Result<QueryValidatorResponse>
pub async fn bridge_validator( &self, address: impl Into<String>, ) -> Result<QueryValidatorResponse>
Queries qorechain.bridge.v1.Query/Validator.
Sourcepub async fn bridge_validators(&self) -> Result<QueryValidatorsResponse>
pub async fn bridge_validators(&self) -> Result<QueryValidatorsResponse>
Queries qorechain.bridge.v1.Query/Validators.
Sourcepub async fn bridge_operation(
&self,
id: impl Into<String>,
) -> Result<QueryOperationResponse>
pub async fn bridge_operation( &self, id: impl Into<String>, ) -> Result<QueryOperationResponse>
Queries qorechain.bridge.v1.Query/Operation.
Sourcepub async fn bridge_operations(&self) -> Result<QueryOperationsResponse>
pub async fn bridge_operations(&self) -> Result<QueryOperationsResponse>
Queries qorechain.bridge.v1.Query/Operations.